@@ -1,5 +1,4 @@
 import json
-import logging
 
 import ccxt
 import pandas as pd
@@ -14,29 +13,28 @@ class LoadDataKline:
         self.exchange = exchange
         super(LoadDataKline, self).__init__(*args, **kwargs)
 
-    def load_all(self):
+    def load_all(self, *args, **kwargs):
         self.exchange.load_markets()
         for sym in tqdm(self.exchange.symbols):
             if ':' not in sym:
-                self.load(sym)
+                self.load(sym, *args, **kwargs)
 
-    def load(self, symbol, timeframe='1m', max_retries=3):
-        limit = 100
+    def load(self, symbol, timeframe='1m', max_retries=3, *args, **kwargs):
+        limit = 1440
         earliest_timestamp = self.exchange.milliseconds()
         timeframe_duration_in_seconds = self.exchange.parse_timeframe(timeframe)
         timeframe_duration_in_ms = timeframe_duration_in_seconds * 1000
         timedelta = limit * timeframe_duration_in_ms
         result_dictionary = {}
 
-        pbar = tqdm(range(1000), desc=symbol)
+        pbar = tqdm(range(100), desc=symbol)
         for _ in pbar:
             fetch_since = earliest_timestamp - timedelta
             result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit)
-            pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
 
             if len(result) == 0:
                 continue
-
+            pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
             result_dictionary = self.exchange.extend(result_dictionary, self.exchange.indexBy(result, 0))
             result_list = self.exchange.sort_by(result_dictionary.values(), 0)
 
